==========
fio-planet
==========

A package of Fiona CLI plugins from Planet Labs.

.. toctree::
   :caption: User Guide
   :hidden:

   examples
   simplification

Indices and Tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`